verify_commitment

Function verify_commitment 

pub fn verify_commitment(
    context: &str,
    commitment: &Commitment,
    value: &[u8],
    opening: &Opening,
) -> Result<()>
Check that commitment opens to value under opening and context.

Errors

Returns Error::CommitmentMismatch if the recomputed commitment does not equal commitment (wrong value, wrong opening, or wrong context).