partial_width

Function partial_width 

pub fn partial_width(level: u8, size: u64) -> u16
The partial-tile width for level in a tree of size leaves: floor(size / 256^level) mod 256. A return of 0 means there is no tile at this level for this size (it is exactly tile-aligned with nothing left over).